@@ -17,8 +17,8 @@ __author_email__ = 'bpitcher@orcasinc.com'
 __copyright__ = 'Copyright 2012-2015 ORCAS'
 __license__ = 'Apache 2.0'
 
-__version__ = '0.2'
-__release__ = '0.2'
+__version__ = '0.2.3'
+__release__ = '0.2.3'
 
 # Module namespace.
 
