@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import base64
 import datetime
 import json
 import requests
@@ -11,7 +10,7 @@ except ImportError:
     from urllib import urlencode
 
 from requests_oauthlib import OAuth2, OAuth2Session
-from oauthlib.oauth2 import TokenExpiredError
+from oauthlib.oauth2.rfc6749.errors import TokenExpiredError
 from fitbit.exceptions import (BadResponse, DeleteError, HTTPBadRequest,
                                HTTPUnauthorized, HTTPForbidden,
                                HTTPServerError, HTTPConflict, HTTPNotFound,
@@ -68,7 +67,7 @@ class FitbitOauth2Client(object):
         try:
             auth = OAuth2(client_id=self.client_id, token=self.token)
             response = self._request(method, url, data=data, auth=auth, **kwargs)
-        except TokenExpiredError as e:
+        except (HTTPUnauthorized, TokenExpiredError) as e:
             self.refresh_token()
             auth = OAuth2(client_id=self.client_id, token=self.token)
             response = self._request(method, url, data=data, auth=auth, **kwargs)
@@ -79,12 +78,11 @@ class FitbitOauth2Client(object):
         if response.status_code == 401:
             d = json.loads(response.content.decode('utf8'))
             try:
-                if(d['errors'][0]['errorType'] == 'oauth' and
-                    d['errors'][0]['fieldName'] == 'access_token' and
-                    d['errors'][0]['message'].find('Access token invalid or expired:') == 0):
-                            self.refresh_token()
-                            auth = OAuth2(client_id=self.client_id, token=self.token)
-                            response = self._request(method, url, data=data, auth=auth, **kwargs)
+                if(d['errors'][0]['errorType'] == 'expired_token' and
+                    d['errors'][0]['message'].find('Access token expired:') == 0):
+                        self.refresh_token()
+                        auth = OAuth2(client_id=self.client_id, token=self.token)
+                        response = self._request(method, url, data=data, auth=auth, **kwargs)
             except:
                 pass
 
@@ -159,16 +157,12 @@ class FitbitOauth2Client(object):
         obtained in step 2.
         the token is internally saved
         """
-
-        unenc_str = (self.client_id + ':' + self.client_secret).encode('utf8')
-        headers = {
-            'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
-            'Authorization': b'Basic ' + base64.b64encode(unenc_str)
-        }
         self.token = self.oauth.refresh_token(
             self.refresh_token_url,
             refresh_token=self.token['refresh_token'],
-            headers=headers)
+            auth=requests.auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        )
+
         return self.token
 
 
